==> Rmixmod_1.1.0.tar.gz: Rmixmod/src/MIXMOD/XEMLearnModelOutput.h <==
/***************************************************************************
 SRC/MIXMOD/XEMLearnModelOutput.h  description
 copyright            : (C) MIXMOD Team - 2001-2011
 email                : contact@mixmod.org
 ***************************************************************************/

/***************************************************************************
 This file is part of MIXMOD
 
 MIXMOD is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 MIXMOD is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
 All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
#ifndef XEMLEARNMODELOUTPUT_H
#define XEMLEARNMODELOUTPUT_H


#include "XEMModelOutput.h"

// pre-declaration
class XEMModel;

class XEMLearnModelOutput : public XEMModelOutput{
  
public:
  
  /// Default Constructor
  XEMLearnModelOutput();
  
  /// Initialization Constructor 1
  XEMLearnModelOutput(XEMModel * estimation);
  
  /// Initialization Constructor 2
  XEMLearnModelOutput(XEMModelType & modelType, int64_t nbCluster, vector<XEMCriterionOutput> & criterionOutput, double likelihood, XEMParameterDescription & parameterDescription, XEMLabelDescription & labelDescription,  XEMProbaDescription & probaDescription);
  
  /// Initialization Constructor 3
  XEMLearnModelOutput(XEMModelType & modelType, int64_t nbCluster, XEMErrorType error);
  
  /// Copy Constructor
  XEMLearnModelOutput(const XEMLearnModelOutput & cModelOutput);
  
  
  /// Destructor
  virtual ~XEMLearnModelOutput();
  
  
  /// set CV Labels
  void setCVLabel(XEMModel * estimation, std::vector<int64_t> & cvLabel);
  
  /// get CV Label
  const XEMLabelDescription * getCVLabel() const;
  
private:
  // label from CV criterion
  XEMLabelDescription * _CVLabel;
};


inline const XEMLabelDescription * XEMLearnModelOutput::getCVLabel() const{
  return _CVLabel;
}

#endif

==> Rmixmod_1.1.1.tar.gz: Rmixmod/src/MIXMOD/XEMLearnModelOutput.h <==
/***************************************************************************
 SRC/MIXMOD/XEMLearnModelOutput.h  description
 copyright            : (C) MIXMOD Team - 2001-2011
 email                : contact@mixmod.org
 ***************************************************************************/

/***************************************************************************
 This file is part of MIXMOD
 
 MIXMOD is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 MIXMOD is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
 All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
#ifndef XEMLEARNMODELOUTPUT_H
#define XEMLEARNMODELOUTPUT_H


#include "XEMModelOutput.h"

// pre-declaration
class XEMModel;

class XEMLearnModelOutput : public XEMModelOutput{
  
public:
  
  /// Default Constructor
  XEMLearnModelOutput();
  
  /// Initialization Constructor 1
  XEMLearnModelOutput(XEMModel * estimation);
  
  /// Initialization Constructor 2
  XEMLearnModelOutput(XEMModelType & modelType, int64_t nbCluster, std::vector<XEMCriterionOutput> & criterionOutput, double likelihood, XEMParameterDescription & parameterDescription, XEMLabelDescription & labelDescription,  XEMProbaDescription & probaDescription);
  
  /// Initialization Constructor 3
  XEMLearnModelOutput(XEMModelType & modelType, int64_t nbCluster, XEMErrorType error);
  
  /// Copy Constructor
  XEMLearnModelOutput(const XEMLearnModelOutput & cModelOutput);
  
  
  /// Destructor
  virtual ~XEMLearnModelOutput();
  
  
  /// set CV Labels
  void setCVLabel(XEMModel * estimation, std::vector<int64_t> & cvLabel);
  
  /// get CV Label
  const XEMLabelDescription * getCVLabel() const;
  
private:
  // label from CV criterion
  XEMLabelDescription * _CVLabel;
};


inline const XEMLabelDescription * XEMLearnModelOutput::getCVLabel() const{
  return _CVLabel;
}

#endif
